transform_flops

Function transform_flops 

pub fn transform_flops(n: usize) -> u128
n*log2(n) butterflies; a length that is no power of two is Bluestein’s three transforms over the next one past 2n-1.