pub struct Map {
pub a: i128,
pub b: i128,
pub d: i128,
pub between: Between,
}Expand description
Reader sample n reads source sample (a*n + b)/d, d > 0: exactly, or rounded down or
to the nearest, ties to even. An exact map is whole, d = 1; nothing reads between samples.
Fields
a: i128b: i128d: i128between: BetweenImplementations
Sourceimpl Map
impl Map
pub const fn shift(b: i64) -> Map
Sourcepub fn new(a: i128, b: i128, d: i128) -> Option<Map>
pub fn new(a: i128, b: i128, d: i128) -> Option<Map>
Lowest terms; None where a sample lands between two, or past what a map holds.
Sourcepub fn rounded(a: i128, b: i128, d: i128, between: Between) -> Option<Map>
pub fn rounded(a: i128, b: i128, d: i128, between: Between) -> Option<Map>
A rounding every sample takes alike is folded into an exact map.
pub fn at(self, n: i64) -> i64
pub fn ahead(self) -> bool
pub fn lead(self) -> i64
pub fn least(self) -> i64
pub fn image(self, over: Extent) -> Extent