pub enum SampleError {
HopOutsideCola {
window: usize,
hop: usize,
},
WindowNotPowerOfTwo {
window: usize,
},
WidthMismatch {
left: usize,
right: usize,
},
ChannelOutOfRange {
k: usize,
width: usize,
},
GridTooLarge {
model: &'static str,
nodes: usize,
ceiling: usize,
},
StringPastRate {
model: &'static str,
},
}Variants
HopOutsideCola
WindowNotPowerOfTwo
WidthMismatch
ChannelOutOfRange
GridTooLarge
A grid sized from the rate and the fundamental, past what one call may allocate.
StringPastRate
A string no stable grid at this rate rings at the partials it was asked for.
Implementations